@@ -1,23 +1,9 @@
 /*  This file is part of the KDE project
-    Copyright (C) 2007-2008 Gökçen Eraslan <gokcen@pardus.org.tr>
-    Copyright (C) 2008 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
-    Copyright (C) 2010 Dario Freddi <drf@kde.org>
-
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2007-2008 Gökçen Eraslan <gokcen@pardus.org.tr>
+    SPDX-FileCopyrightText: 2008 Daniel Nicoletti <dantti85-pk@yahoo.com.br>
+    SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
 
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef AUTHDIALOG_H
@@ -58,14 +44,14 @@ public:
 
     PolkitQt1::ActionDescription m_actionDescription;
 
-signals:
+Q_SIGNALS:
     void adminUserSelected(PolkitQt1::Identity);
     void okClicked();
 
-public slots:
+public Q_SLOTS:
     void accept() override;
 
-private slots:
+private Q_SLOTS:
     void checkSelectedUser();
 
 private:
@@ -80,7 +66,7 @@ class AuthDetails : public QWidget, private Ui::AuthDetails
 public:
     AuthDetails(const PolkitQt1::Details &details, const PolkitQt1::ActionDescription &actionDescription, QWidget *parent);
 
-private slots:
+private Q_SLOTS:
     void openUrl(const QString &);
 };
 
